---
name: Bug Report
about: Create a report to help us improve lazy-text-classifiers
labels: bug
---

<!--
  ⚠️⚠️ Please do the following before submitting: ⚠️⚠️

  📖 Please read our Code of Conduct.
  🔎 Please search existing issues to avoid creating duplicates.
-->

### Describe the Bug

<!-- A clear and concise description of the bug. -->

### Expected Behavior

<!-- What did you expect to happen instead? -->

### Reproduction

<!-- Steps to reproduce the behavior and/or a minimal example that exhibits the behavior. -->

### Environment

<!-- Any additional information about your environment. -->

-   OS Version: _[e.g. macOS 11.3.1]_
-   lazy-text-classifiers Version: _[e.g. 0.5.0]_
